@@ -11,7 +11,7 @@ use Carp;
 use List::Util qw(all);
 use Scalar::Util::Numeric qw(isint);
 
-our $VERSION = '0.0101'; # VERSION
+our $VERSION = '0.0102'; # VERSION
 
 use Config;
 BEGIN {
@@ -172,7 +172,7 @@ Crypt::XXTEA_PP - Pure Perl Implementation of Corrected Block Tiny Encryption Al
 
 =head1 VERSION
 
-version 0.0101
+version 0.0102
 
 =head1 SYNOPSIS
 
@@ -224,7 +224,7 @@ Encrypts blocksize() bytes of $plain_text and returns the corresponding cipherte
 
 =head2 decrypt
 
-    $plain_text = $xtea->decrypt($cipher_text);
+    $plain_text = $xxtea->decrypt($cipher_text);
 
 Decrypts blocksize() bytes of $cipher_text and returns the corresponding plaintext.
 
@@ -232,6 +232,8 @@ Decrypts blocksize() bytes of $cipher_text and returns the corresponding plainte
 
 L<Crypt::CBC>
 
+L<Crypt::XXTEA_XS>
+
 =head1 AUTHOR
 
 Kars Wang <jahiy@cpan.org>
